pydrobert.kaldi.eval
====================

.. automodule:: pydrobert.kaldi.eval
    :members:
    :undoc-members:
    :show-inheritance:


.. toctree::
    :maxdepth: 1
    :caption: Submodules:

    pydrobert.kaldi.eval.util
